/*
 * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */

import React from 'react'
import ServicesList from './ServicesList'
import {Toggle, DropDownMenu, MenuItem, IconButton, Paper} from 'material-ui'

export default React.createClass({

    mixins:[AdminComponents.MessagesConsumerMixin],

    propTypes:{
        dataModel:React.PropTypes.instanceOf(PydioDataModel).isRequired,
        rootNode:React.PropTypes.instanceOf(AjxpNode).isRequired,
        currentNode:React.PropTypes.instanceOf(AjxpNode).isRequired,
        openEditor:React.PropTypes.func.isRequired,
        openRightPane:React.PropTypes.func.isRequired,
        closeRightPane:React.PropTypes.func.isRequired
    },

    componentDidMount: function(){
        this.refs.servicesList.reload();
    },

    getInitialState:function(){
        return {details: true, filter:''}
    },

    onDetailsChange: function(event, value){
        this.setState({details: value});
    },

    onFilterChange: function(event, index, value){
        this.setState({filter: value});
    },

    reloadList:function(){
        this.refs.servicesList.reload();
    },

    render:function(){
        const buttonContainer = (
            <div style={{borderBottom: '1px solid rgba(0,0,0,0.1)'}}>
                <div style={{display: 'flex', alignItems: 'baseline', padding: '0 20px', width: '100%'}}>
                    <span className="hide-on-vertical-layout">{this.context.getMessage('173', 'settings')}</span>
                    <span className="hide-on-vertical-layout" style={{flex: 1}}/>
                    <Toggle label={"Show Details"} toggled={this.state.details} onToggle={this.onDetailsChange} labelPosition={"right"} style={{width: 150}}/>
                    <DropDownMenu underlineStyle={{display:'none'}} value={this.state.filter} onChange={this.onFilterChange}>
                        <MenuItem value={''} primaryText="No filter" />
                        <MenuItem value={'STARTED'} primaryText="Running Only" />
                        <MenuItem value={'STOPPED'} primaryText="Stopped Only" />
                    </DropDownMenu>
                    <IconButton className="small-icon-button" iconClassName="icon-refresh" onClick={this.reloadList} iconStyle={{color:'rgba(0,0,0,.4)', fontSize: 15}}/>
                </div>
            </div>
        );
        return (
            <div className="main-layout-nav-to-stack workspaces-board">
                <div className="left-nav vertical-layout" style={{width:'100%'}}>
                    <Paper zDepth={0} className="vertical-layout layout-fill" style={{backgroundColor: '#f5f5f5'}}>
                        <div className="vertical-layout layout-fill">
                            <h1 className="admin-panel-title hide-on-vertical-layout">{this.context.getMessage('172', 'settings')}</h1>
                            {buttonContainer}
                            <ServicesList
                                ref="servicesList"
                                dataModel={this.props.dataModel}
                                rootNode={this.props.rootNode}
                                currentNode={this.props.rootNode}
                                filter={this.state.filter}
                                details={this.state.details}
                            />
                        </div>
                    </Paper>
                </div>
            </div>
        );
    }

});