
const React = require('react');
import DataSource from '../model/DataSource'
import Workspace from '../model/Workspace'
import {FlatButton, RaisedButton} from 'material-ui'

class DataSourceEditor extends React.Component{

    constructor(props){
        super(props);
        this.state = {
            dirty:false,
            model: new DataSource(props.node.getMetadata().get('datasource_id')),
            driverInfo: null,
            loaded :false,
            valid: true
        };
    }

    componentDidMount(){
        if (Workspace.DRIVERS) {
            this.setState({driverInfo: Workspace.DRIVERS.get('datasource')});
        } else {
            Workspace.loadAvailableDrivers(() => {
                this.setState({
                    driverInfo: Workspace.DRIVERS.get('datasource')
                });
            });
        }
        this.state.model.load(() => {
            this.setState({loaded: true});
        });
    }

    resetForm(){
        this.setState({valid: true, dirty: false, saveValues: null});
    }

    deleteSource(){
        if(confirm('Are you sure you want to delete this datasource? This is undoable, and you may loose all data linked to these nodes!')){
            this.state.model.deleteSource(()=>{
                this.props.closeEditor();
                this.props.reloadList();
            })
        }
    }

    saveSource(){
        if(this.state.saveValues){
            this.state.model.saveSource(this.state.saveValues, () => {
                this.setState({valid: true, dirty: false, saveValues: null});
                this.props.reloadList();
            });
        }
    }

    onFormChange(values){
        this.setState({saveValues: values, dirty: true});
    }

    updateValidStatus(valid){
        this.setState({valid: valid});
    }

    launchResync(){
        this.state.model.resyncSource();
    }

    render(){
        const {loaded, driverInfo, model} = this.state;
        let form;
        if(driverInfo && loaded){
            let values = model.getDataWithPrefix('DATASOURCE_');
            if (this.state.saveValues){
                values = this.state.saveValues;
            }
            let params = JSON.parse(JSON.stringify(driverInfo.params));
            if(params.length > 2){
                params[0].readonly = true;
                params[0].description = 'You cannot edit datasource name, delete it and create a new one instead.';
                params[1].readonly = true;
                params[1].descripton = 'Changing a datasource path may loose the indexation data and all attached metadata.';
            }
            form = (
                <PydioForm.FormPanel
                    parameters={params}
                    values={values}
                    className="full-width"
                    onChange={this.onFormChange.bind(this)}
                    onValidStatusChange={this.updateValidStatus.bind(this)}
                    depth={-2}
                />
            );
        }

        let titleActionBarButtons = [];
        titleActionBarButtons.push(<FlatButton key="delete" label={'Delete DataSource'} secondary={true} onTouchTap={this.deleteSource.bind(this)}/>);
        titleActionBarButtons.push(<div className="separator" key="separator"></div>);
        titleActionBarButtons.push(<FlatButton key="reset" label={this.context.getMessage('plugins.6')} onTouchTap={this.resetForm.bind(this)} secondary={true} disabled={!this.state.dirty}/>);
        titleActionBarButtons.push(<FlatButton key="save" label={this.context.getMessage('53', '')} onTouchTap={this.saveSource.bind(this)} secondary={true} disabled={!this.state.valid || !this.state.dirty}/>);
        titleActionBarButtons.push(<RaisedButton key="close" label={this.context.getMessage('86', '')} onTouchTap={this.props.closeEditor}/>);

        const leftNav = (
            <div style={{padding: '6px 16px', color: '#9E9E9E', fontSize: 15, lineHeight: '23px', fontWeight: 500}}>
                <div style={{fontSize: 200, paddingBottom: 20}}>
                    <i className="mdi mdi-database"/>
                </div>
                {this.context.getMessage('ws.75')}<br/><br/>
                {this.context.getMessage('ws.76')}
                <div style={{textAlign:'center', marginTop: 16}}>
                    <RaisedButton label={"Resync Datasource"} onClick={this.launchResync.bind(this)}/>
                </div>
            </div>
        );

        return (
            <PydioComponents.PaperEditorLayout
                title={loaded && driverInfo ? "DataSource " + this.state.model.dsId : "Loading..."}
                titleActionBar={titleActionBarButtons}
                leftNav={leftNav}
                className="workspace-editor"
                contentFill={false}
            >
                {form}
            </PydioComponents.PaperEditorLayout>
        );
    }
}

DataSourceEditor.contextTypes = {
    messages    : React.PropTypes.object,
    getMessage  : React.PropTypes.func
};

export {DataSourceEditor as default};