const Observable = require('pydio/lang/observable');
const PydioApi = require('pydio/http/api');

class DataSource extends Observable{

    constructor(dsId){
        super();
        this.dsId = dsId;
        this.loaded = false;
    }

    load(callback){
        if(this.loaded) {
            callback();
            return;
        }
        PydioApi.getClient().request({
            get_action: 'datasource_load',
            dsId: this.dsId,
        }, (t) => {
            this.data = t.responseJSON;
            this.loaded = true;
            callback();
        })

    }

    deleteSource(callback){
        PydioApi.getClient().request({
            get_action: 'datasource_delete',
            dsId: this.dsId,
        }, (t) => {
            callback();
        })
    }

    resyncSource(callback = null){
        PydioApi.getClient().request({
            get_action: 'datasource_resync',
            dsId: this.dsId,
        }, (t) => {
            if (callback) {
                callback();
            }
        })
    }

    saveSource(values, callback){
        PydioApi.getClient().request({
            get_action: 'datasource_edit',
            values: JSON.stringify(values),
        }, (t) => {
            this.data = t.responseJSON;
            this.loaded = true;
            callback();
        })
    }

    getDataWithPrefix(prefix = ''){
        if (prefix === '') {
            return this.data;
        }
        let data = {};

        Object.keys(this.data).forEach((k) => {
            data[prefix + k] = this.data[k];
        });
        return data;
    }

}

export {DataSource as default};