<?php
/*
 * Copyright 2007-2017 Abstrium <contact (at) pydio.com>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com/>.
 */

namespace Pydio\Access\Driver\DataProvider\Provisioning;

use Psr\Http\Message\ResponseInterface;
use Psr\Http\Message\ServerRequestInterface;
use Pydio\Access\Core\Model\Node;
use Pydio\Access\Core\Model\NodesList;
use Pydio\Core\Http\Client\MicroApi;
use Pydio\Core\Services\UsersService;

defined('PYDIO_EXEC') or die('Access not allowed');


class ServicesManager extends AbstractManager{

    public function servicesAction(ServerRequestInterface $requestInterface, ResponseInterface &$responseInterface){

    }

    public function listNodes(ServerRequestInterface $requestInterface, $rootPath, $relativePath, $paginationHash = null, $findNodePosition = null, $aliasedDir = null)
    {
        $nodesList = new NodesList("/$rootPath/$relativePath");

        if(!UsersService::usersEnabled() || $this->currentUserIsGroupAdmin()) {
            return $nodesList;
        }

        $ctxUser    = $this->context->getUser();

        $api = MicroApi::GetConfigServiceApi();
        $response = $api->listServices();
        if ($response->getTotal() === 0) {
            return $nodesList;
        }

        foreach($response->getServices() as $service){

            $key = "/".$rootPath."/".$relativePath."/".$service->getName();
            $meta = [
                "text" => $service->getName(),
                "description" => $service->getDescription(),
                "status" => $service->getStatus(),
                "version" => $service->getDescription(),
                "nodes" => json_encode($service->getRunningNodes()),
                "tag" => $service->getTag()
            ];
            $node = new Node($key, $meta);
            $nodesList->addBranch($node);

        }

        return $nodesList;

    }
}