/*
 * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */
'use strict';

exports.__esModule = true;

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { 'default': obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var _PydioApi = require('./PydioApi');

var _PydioApi2 = _interopRequireDefault(_PydioApi);

var _utilXMLUtils = require('../util/XMLUtils');

var _utilXMLUtils2 = _interopRequireDefault(_utilXMLUtils);

var _langObservable = require('../lang/Observable');

var _langObservable2 = _interopRequireDefault(_langObservable);

var _MetaCacheService = require('./MetaCacheService');

var _MetaCacheService2 = _interopRequireDefault(_MetaCacheService);

var User = (function (_Observable) {
    _inherits(User, _Observable);

    function User(id, label, type, group, avatar, temporary, external, extendedLabel) {
        _classCallCheck(this, User);

        _Observable.call(this);
        this._id = id;
        this._label = label;
        this._type = type;
        if (this._type === 'group') {
            this._group = id;
        }
        this._avatar = avatar;
        this._temporary = temporary;
        this._external = external;
        this._extendedLabel = extendedLabel;
    }

    User.fromObject = function fromObject(user) {
        return new User(user.id, user.label, user.type, user.group, user.avatar, user.temporary, user.external);
    };

    User.prototype.asObject = function asObject() {
        return {
            id: this._id,
            label: this._label,
            type: this._type,
            group: this._group,
            avatar: this._avatar,
            temporary: this._temporary,
            external: this._external,
            extendedLabel: this._extendedLabel
        };
    };

    User.prototype.getId = function getId() {
        return this._id;
    };

    User.prototype.getLabel = function getLabel() {
        return this._label;
    };

    User.prototype.setLabel = function setLabel(label) {
        this._label = label;
    };

    User.prototype.getGraph = function getGraph() {
        return this._graph;
    };

    User.prototype.setGraph = function setGraph(graph) {
        this._graph = graph;
    };

    User.prototype.getType = function getType() {
        return this._type;
    };

    User.prototype.getGroup = function getGroup() {
        return this._group;
    };

    User.prototype.getAvatar = function getAvatar() {
        return this._avatar;
    };

    User.prototype.setAvatar = function setAvatar(avatar) {
        this._avatar = avatar;
    };

    User.prototype.getTemporary = function getTemporary() {
        return this._temporary;
    };

    User.prototype.getExternal = function getExternal() {
        return this._external;
    };

    User.prototype.getExtendedLabel = function getExtendedLabel() {
        return this._extendedLabel;
    };

    User.prototype.isLoading = function isLoading() {
        return this._loading;
    };

    User.prototype.setLoaded = function setLoaded() {
        this._loading = false;
        this.notify('loaded');
    };

    User.prototype.setLoading = function setLoading() {
        this._loading = true;
    };

    User.prototype.setLocal = function setLocal() {
        this._local = true;
    };

    User.prototype.isLocal = function isLocal() {
        return this._local;
    };

    return User;
})(_langObservable2['default']);

var UsersApi = (function () {
    function UsersApi() {
        _classCallCheck(this, UsersApi);
    }

    UsersApi.authorizedUsersStartingWith = function authorizedUsersStartingWith(token, callback) {
        var usersOnly = arguments.length <= 2 || arguments[2] === undefined ? false : arguments[2];
        var existingOnly = arguments.length <= 3 || arguments[3] === undefined ? false : arguments[3];

        var params = {
            get_action: 'user_list_authorized_users',
            value: token,
            format: 'json'
        };
        if (usersOnly) {
            params['users_only'] = 'true';
        }
        if (existingOnly) {
            params['existing_only'] = 'true';
        }
        _PydioApi2['default'].getClient().request(params, function (transport) {
            var suggestions = [];
            if (transport.responseXML) {
                var lis = _utilXMLUtils2['default'].XPathSelectNodes(transport.responseXML, '//li');
                lis.map(function (li) {
                    var spanLabel = _utilXMLUtils2['default'].XPathGetSingleNodeText(li, 'span[@class="user_entry_label"]');
                    suggestions.push(new User(li.getAttribute('data-entry_id'), li.getAttribute('data-label'), li.getAttribute('class'), li.getAttribute('data-group'), li.getAttribute('data-avatar'), !!li.getAttribute('data-temporary'), li.getAttribute('data-external') == 'true', spanLabel));
                });
            } else if (transport.responseJSON) {
                var data = transport.responseJSON;
                data.map(function (entry) {
                    var id = entry.id;
                    var label = entry.label;
                    var type = entry.type;
                    var group = entry.group;
                    var avatar = entry.avatar;
                    var temporary = entry.temporary;
                    var external = entry.external;

                    suggestions.push(new User(id, label, type, group, avatar, temporary, external, label));
                });
            }
            callback(suggestions);
        });
    };

    UsersApi.createUserFromPost = function createUserFromPost(postValues, callback) {
        postValues['get_action'] = 'user_create_user';
        _PydioApi2['default'].getClient().request(postValues, (function (transport) {
            callback(postValues, transport.responseJSON);
        }).bind(this));
    };

    UsersApi.deleteUser = function deleteUser(userId, callback) {
        _PydioApi2['default'].getClient().request({
            get_action: 'user_delete_user',
            user_id: userId
        }, function (transport) {
            callback();
        });
    };

    UsersApi.saveSelectionSupported = function saveSelectionSupported() {
        return global.pydio.getController().actions.get('user_team_create') !== undefined;
    };

    UsersApi.deleteTeam = function deleteTeam(teamId, callback) {
        teamId = teamId.replace('/USER_TEAM/', '');
        _PydioApi2['default'].getClient().request({
            get_action: 'user_team_delete',
            team_id: teamId
        }, function (transport) {
            callback(transport.responseJSON);
        });
    };

    UsersApi.saveSelectionAsTeam = function saveSelectionAsTeam(teamName, userIds, callback) {
        _PydioApi2['default'].getClient().request({
            get_action: 'user_team_create',
            team_label: teamName,
            'user_ids[]': userIds
        }, function (transport) {
            callback(transport.responseJSON);
        });
    };

    UsersApi.addUserToTeam = function addUserToTeam(teamId, userId, callback) {
        teamId = teamId.replace('/USER_TEAM/', '');
        _PydioApi2['default'].getClient().request({
            get_action: 'user_team_add_user',
            team_id: teamId,
            user_id: userId
        }, function (transport) {
            callback(transport.responseJSON);
        });
    };

    UsersApi.removeUserFromTeam = function removeUserFromTeam(teamId, userId, callback) {
        teamId = teamId.replace('/USER_TEAM/', '');
        _PydioApi2['default'].getClient().request({
            get_action: 'user_team_delete_user',
            team_id: teamId,
            user_id: userId
        }, function (transport) {
            callback(transport.responseJSON);
        });
    };

    UsersApi.updateTeamLabel = function updateTeamLabel(teamId, newLabel, callback) {
        teamId = teamId.replace('/USER_TEAM/', '');
        _PydioApi2['default'].getClient().request({
            get_action: 'user_team_update_label',
            team_id: teamId,
            team_label: newLabel
        }, function (transport) {
            callback(transport.responseJSON);
        });
    };

    /**
     *
     * @param userObject User
     * @param loadGraph Object
     * @param callback Function
     */

    UsersApi.loadPublicData = function loadPublicData(userObject, loadGraph, callback) {

        var userId = userObject.getId();
        _PydioApi2['default'].getClient().request({
            get_action: 'user_public_data',
            user_id: userId,
            graph: loadGraph
        }, (function (transport) {
            var data = transport.responseJSON;
            if (!data || data.error) {
                userObject.setLabel(userId);
                callback(userObject);
                return;
            }
            var user = data.user;
            var graph = data.graph;

            var avatarUrl = undefined;
            var avatarId = user.avatar || null;
            var label = user.label || userId;
            userObject.setGraph(graph);
            userObject.setLabel(label);
            if (user.avatar) {
                avatarUrl = UsersApi.buildUserAvatarUrl(userId, avatarId);
                userObject.setAvatar(avatarUrl);
                callback(userObject);
            } else {
                UsersApi.avatarFromExternalProvider(userObject, callback);
            }
        }).bind(this));
    };

    UsersApi.loadLocalData = function loadLocalData(userObject, callback) {

        var pydio = _PydioApi2['default'].getClient().getPydioObject();
        if (!pydio || !pydio.user) {
            callback(userObject);
            return;
        }
        //const userName = pydio.user.getPreference('displayName') || pydio.user.id;
        userObject.setLabel('You');

        var avatarUrl = UsersApi.buildUserAvatarUrl(pydio.user.id, pydio.user.getPreference('avatar'));
        if (avatarUrl) {
            userObject.setAvatar(avatarUrl);
            callback(userObject);
        } else if (pydio.user.preferences.has('external_avatar_loaded')) {
            callback(userObject);
        } else {
            UsersApi.avatarFromExternalProvider(userObject, function (userObject) {
                callback(userObject);
                pydio.user.preferences.set('external_avatar_loaded', true);
            });
        }
    };

    /**
     * Try to load avatar from plugin
     * @param userObject
     * @param callback
     */

    UsersApi.avatarFromExternalProvider = function avatarFromExternalProvider(userObject, callback) {

        callback(userObject);
        return;

        if (UsersApi.avatarsCache[userObject.getId] !== undefined) {
            userObject.setAvatar(UsersApi.avatarsCache[userObject.getId]);
            callback(userObject);
            return;
        }

        if (_PydioApi2['default'].getClient().getPydioObject().getPluginConfigs("plugin[@id='action.avatar']").get("AVATAR_PROVIDER")) {
            callback(userObject);
            return;
        }
        _PydioApi2['default'].getClient().request({
            get_action: 'get_avatar_url',
            userid: userObject.getId()
        }, (function (transport) {
            UsersApi.avatarsCache[userObject.getId()] = transport.responseText;
            userObject.setAvatar(transport.responseText);
            callback(userObject);
        }).bind(this));
    };

    /**
     * Build avatar url from avatarId
     * @param userId
     * @param avatarId
     * @returns {*}
     */

    UsersApi.buildUserAvatarUrl = function buildUserAvatarUrl(userId) {
        var avatarId = arguments.length <= 1 || arguments[1] === undefined ? null : arguments[1];

        if (avatarId) {
            return _PydioApi2['default'].getClient().getPydioObject().Parameters.get('ajxpServerAccess') + "&get_action=get_binary_param&binary_id=" + avatarId + "&user_id=" + userId;
        } else {
            return null;
        }
    };

    UsersApi.getPublicDataCache = function getPublicDataCache() {
        var cache = _MetaCacheService2['default'].getInstance();
        cache.registerMetaStream('user_public_data', 'EXPIRATION_MANUAL_TRIGGER');
        cache.registerMetaStream('user_public_data-graph', 'EXPIRATION_MANUAL_TRIGGER');
        return cache;
    };

    UsersApi.getUserPromise = function getUserPromise(userId) {
        var withGraph = arguments.length <= 1 || arguments[1] === undefined ? false : arguments[1];

        var namespace = withGraph ? 'user_public_data-graph' : 'user_public_data';
        var cache = UsersApi.getPublicDataCache();
        var pydio = _PydioApi2['default'].getClient().getPydioObject();

        return new Promise(function (resolve, reject) {
            if (pydio && pydio.user && pydio.user.id === userId) {
                var userObject = new User(userId);
                UsersApi.loadLocalData(userObject, function (result) {
                    result.setLocal();
                    resolve(result);
                });
                return;
            }
            if (cache.hasKey(namespace, userId)) {
                (function () {
                    var obj = cache.getByKey(namespace, userId);
                    if (obj.isLoading()) {
                        obj.observe('loaded', function () {
                            resolve(obj);
                        });
                    } else {
                        resolve(obj);
                    }
                })();
            } else {
                var userObject = new User(userId);
                userObject.setLoading();
                cache.setKey(namespace, userId, userObject);

                UsersApi.loadPublicData(userObject, withGraph, function (result) {
                    result.setLoaded();
                    cache.setKey(namespace, userId, result);
                    resolve(result);
                });
            }
        });
    };

    return UsersApi;
})();

UsersApi.avatarsCache = [];

exports.User = User;
exports.UsersApi = UsersApi;
