/*
 * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */

'use strict';

exports.__esModule = true;

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError('Cannot call a class as a function'); } }

function _inherits(subClass, superClass) { if (typeof superClass !== 'function' && superClass !== null) { throw new TypeError('Super expression must either be null or a function, not ' + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

var PydioWebSocket = require('pydio/http/websocket');
var ReconnectingWebSocket = require('reconnecting-websocket');

var ChatClient = (function (_PydioWebSocket) {
    _inherits(ChatClient, _PydioWebSocket);

    function ChatClient(pydioObject, roomType, objectId, messageHandler) {
        _classCallCheck(this, ChatClient);

        _PydioWebSocket.call(this, pydioObject);
        this.currentRepo = pydioObject.repositoryId;
        this.messageHandler = messageHandler;
        this.messages = [];
        this.roomType = roomType;
        this.objectId = objectId;
    }

    ChatClient.prototype.send = function send(message) {
        this.ws.send(message);
    };

    ChatClient.prototype.open = function open() {
        var _this = this;

        this.close();
        if (!this.currentRepo) {
            return;
        }
        var url = this.pydio.getPluginConfigs("core.conf").get("ENDPOINT_WEBSOCKET").replace("/ws", "/chat");
        this.ws = new ReconnectingWebSocket(url);

        this.ws.addEventListener('open', function () {
            PydioWebSocket.subscribeJWT(_this.ws);
            _this.joinRoom(_this.ws);
        });
        this.ws.addEventListener('message', function (msg) {
            console.log(msg);
            _this.messages.push(msg);
            _this.messageHandler(msg);
        });
        this.ws.addEventListener('close', function (event) {
            PydioWebSocket.logClose(event);
        });
    };

    ChatClient.prototype.close = function close() {
        if (this.ws === null) {
            return;
        }
        this.leaveRoom(this.ws);
        _PydioWebSocket.prototype.close.call(this);
    };

    ChatClient.prototype.joinRoom = function joinRoom(ws) {
        var message = { "@type": "JOIN", "Room": { "Type": this.roomType, "RoomTypeObject": this.objectId } };
        ws.send(JSON.stringify(message));
    };

    ChatClient.prototype.leaveRoom = function leaveRoom(ws) {
        var message = { "@type": "LEAVE", "Room": { "Type": this.roomType, "RoomTypeObject": this.objectId } };
        ws.send(JSON.stringify(message));
        this.messages = [];
        this.messageHandler();
    };

    ChatClient.prototype.getMessages = function getMessages() {
        return this.messages;
    };

    return ChatClient;
})(PydioWebSocket);

exports['default'] = ChatClient;
module.exports = exports['default'];
