/*
 * Copyright 2007-2017 Charles du Jeu - Abstrium SAS <team (at) pyd.io>
 * This file is part of Pydio.
 *
 * Pydio is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Affero General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Pydio is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Affero General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public License
 * along with Pydio.  If not, see <http://www.gnu.org/licenses/>.
 *
 * The latest code can be found at <https://pydio.com>.
 */

const React = require('react');
const {PydioContextConsumer} = require('pydio').requireLib('boot');
const ChatClient = require('./ChatClient');
const Message = require('./Message');

class Chat extends React.Component{

    constructor(props){
        super(props);
        this.client = null;
        this.state = {messages: [], room: null, value:""};
    }

    componentDidMount(){
        this.start();
    }

    componentWillUnmount(){
        this.stop();
    }

    componentDidUpdate(){
        this.refs.comments.scrollTop = 100000;
    }

    onNewMessage(msg){
        if (msg){
            const data = JSON.parse(msg['data']);
            if (data['@type'] === 'ROOM_UPDATE') {
                this.setState({room: data['Room']});
            }
            this.setState({messages: this.client.getMessages()});
        }
    }

    start(){
        const {pydio, roomType, roomObjectId} = this.props;
        this.client = new ChatClient(pydio, roomType, roomObjectId, this.onNewMessage.bind(this));
        this.client.open();
    }

    stop(){
        this.client.close();
    }

    postMessage(){
        if (!this.state.value) {
            return;
        }
        if (!this.state.room || !this.state.room.Uuid){
            return;
        }
        let message = {
            "@type":"POST",
            "Message":{"RoomUuid":this.state.room.Uuid, "Message":this.state.value}
        };
        this.client.send(JSON.stringify(message));
        this.setState({value: ''});
    }

    keyDown(event){
        if(event.key === 'Enter'){
            event.preventDefault();
            this.postMessage();
        }
    }

    render(){
        const {messages} = this.state;
        let data = [];
        messages.forEach((m) => {
            let mData = JSON.parse(m['data']);
            if(mData['Message']){
                data.push(<Message key={mData.Uuid} message={mData}/>);
            }
        });
        return (
            <div style={{padding: 0}}>
                <div ref="comments" className="comments_feed" style={{maxHeight: 300, overflowY: 'auto'}}>{data}</div>
                <MaterialUI.Divider/>
                <div style={{backgroundColor: 'white'}}>
                    <MaterialUI.TextField
                        hintText={this.props.pydio.MessageHash['meta.comments.2']}
                        hintStyle={{whiteSpace:'nowrap'}}
                        value={this.state.value}
                        onChange={(event, newValue) => {this.setState({value: newValue})}}
                        multiLine={true}
                        ref="new_comment"
                        onKeyDown={this.keyDown.bind(this)}
                        fullWidth={true}
                        underlineShow={false}
                        style={{marginLeft: 16, marginRight: 16}}
                    />
                </div>
            </div>
        )
    }

}

Chat.PropTypes = {
    roomType : React.PropTypes.string,
    roomObjectId: React.PropTypes.string,
};

Chat = PydioContextConsumer(Chat);
export {Chat as default};